Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
__init__.py | 20 | 0 | 0 | 100%
cards/__init__.py | 52 | 12 | 0 | 77%
cards/axis.py | 20 | 2 | 0 | 90%
cards/elements.py | 205 | 128 | 0 | 38%
cards/loading.py | 96 | 10 | 0 | 90%
cards/materials.py | 14 | 0 | 0 | 100%
cards/properties.py | 105 | 22 | 0 | 79%
cards/types.py | 1 | 0 | 0 | 100%
cardslib.py | 675 | 334 | 0 | 51%
cli.py | 34 | 18 | 0 | 47%
constants.py | 21 | 0 | 0 | 100%
decorators.py | 223 | 95 | 0 | 57%
fields_writer.py | 95 | 26 | 0 | 73%
mesh_api/__init__.py | 1 | 0 | 0 | 100%
mesh_api/mesh_api.py | 1139 | 567 | 0 | 50%
mesh_api/mod.py | 158 | 140 | 0 | 11%
mesh_api/rtree_indexes.py | 122 | 100 | 0 | 18%
pylib.py | 26 | 5 | 0 | 81%
readers/__init__.py | 0 | 0 | 0 | 100%
readers/bulk.py | 350 | 224 | 0 | 36%
readers/gmsh/__init__.py | 1 | 0 | 0 | 100%
readers/gmsh/gmsh.py | 200 | 170 | 0 | 15%
readers/gmsh/mixins.py | 82 | 72 | 0 | 12%
readers/gmsh/study.py | 301 | 264 | 0 | 12%
readers/gmsh/ui_versions/__init__.py | 0 | 0 | 0 | 100%
readers/gmsh/ui_versions/user_input_v1.py | 82 | 65 | 0 | 21%
readers/gmsh/ui_versions/user_input_v2.py | 137 | 111 | 0 | 19%
readers/gmsh/user_input.py | 4 | 2 | 0 | 50%
readers/op2.py | 131 | 106 | 0 | 19%
registry.py | 203 | 89 | 0 | 56%
serializer.py | 43 | 30 | 0 | 30%
types.py | 6 | 2 | 0 | 67%
utils.py | 145 | 68 | 0 | 53%
writers/__init__.py | 0 | 0 | 0 | 100%
writers/femap_neutral.py | 214 | 177 | 0 | 17%
writers/templates/__init__.py | 0 | 0 | 0 | 100%
Total | 4906 | 2839 | 0 | 42%

No items found using the specified filter.